<?php
// File: $Id: envRender.php,v 1.6 2002/09/28 06:30:28 madhatter7 Exp $ $Name:  $
// Copyright (c) 2002 by the Envolution Development Team
// http://www.envolution.com
// Envolution Content Management System - http://www.envolution.com
//
// ----------------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please read the docs/license.txt or visit
// http://www.gnu.org/copyleft/gpl.html
//
// ----------------------------------------------------------------------------
// Filename:	Envolution Template System API				envRender.php
// Author:		Brian K. Virgin (MADHATter7)
// Purpose:		API Functions for templated modules/blocks
// ----------------------------------------------------------------------------
//
// ----------------------------------------------------------------------------


////
// Start the template page output
// @access		public
// @author		mh7
// @param		string	$module		the name of the module
// @param		string	$template	the name of the template
// @param		int		$control	controls left, right blocks (0,1,3)
// @return		bool				true
// @note		NEARLY ALL MODULES DO NOT NEED TO USE THIS YET
function envTplStart($module, $template, $control=1)
{
	global $renderer, $index;

	// Include the header
	$index = $control;
	include ('header.php');

   	// Load the template engine
	if (!envTplLoadEngine())
	{
		pnSessionSetVar('errormsg', _FPTPLENGLOADFAILED);
		return false;
	}

	// Determine which Theme to use
    if (pnUserLoggedIn())
    {
        // Use the users Theme
        $theme = pnUserGetTheme();
    } else {
        // Use the sites theme
        $theme = pnConfigGetVar('Default_Theme');
    }

	// Get the module's template directory
    $tplpath = envTplGetPath($module, $template, $theme);

	if (empty($tplpath))
	{
		pnSessionSetVar('errormsg', _FPTPLPATHFAILED);
		return false;
	}

    // Setup DTS Main Settings
    $renderer = new Smarty;
    $renderer->compile_check	= true;                      // check for updated templates?
    $renderer->force_compile	= false;                     // force compile template always?
    $renderer->debugging		= false;                     // debugging on/off
    $renderer->left_delimiter	= "[-";                      // begin holder tag (be nice to others)
    $renderer->right_delimiter	= "-]";                      // end holder tag
    $renderer->config_dir		= "themes/$theme/config";    // default configs path (theme|module)
    $renderer->template_dir		= "$tplpath";                // default directory for templates
    $renderer->compile_dir		= "themes/$theme/xcache";    // cache directory (compiled templates)

	return true;
}


////
// End the template page output
// @access		public
// @author		mh7
// @param		none
// @return		none
// @note		NEARLY ALL MODULES DO NOT NEED TO USE THIS YET
function envTplEnd()
{
	// Future version will end output buffering
	// and deal with unexpected output, etc

	// Include the footer
	include ('footer.php');
	return true;
}


////
// Assign values to template holders
// @access		public
// @author		mh7
// @param		string	$holder		the template holder name
// @param		string	$value		the value to be substitued for the holder
// @return		bool				true
// @note		$holder may also be an array, in which case
//				$value will be empty
function envTplAssign($holder, $value='')
{
	global $renderer;

	$renderer->assign($holder, $value);
	return true;
}


////
// Appends values to template holders
// @access		public
// @author		mh7
// @param		string	$holder		the template holder name
// @param		string	$value		the value to be appended to the holder
// @return		bool				true
// @note		$holder may also be an array, in which case
//				$value will be empty
function envTplAppend($holder, $value='')
{
	global $renderer;

	$renderer->append($holder, $value);
	return true;
}


////
// Clears template holders
// @access		public
// @author		mh7
// @param		string	$holder		the template holder name
// @return		bool				true
// @note		$holder may also be an array
function envTplUnassign($holder)
{
	global $renderer;

	$renderer->clear_assign($holder);
	return true;
}


////
// Register a custom function to be used in templates
// @access		public
// @author		mh7
// @param		string	$holder		the template holder name
// @param		string	$func		the function to execute at the holder
// @return		bool				true
function envTplRegFunc($holder, $func)
{
	global $renderer;

	$renderer->register_function($holder, $func);
	return true;
}


////
// Unregisters a custom function for templates
// @access		public
// @author		mh7
// @param		string	$holder		the holder tag for the function
// @return		bool				true
function envTplUnRegFunc($holder)
{
	global $renderer;

	$renderer->unregister_function($holder);
	return true;
}


////
// Display the template
// @access		public
// @author		mh7
// @param		string	$template	the template to render
// @return		bool				true
function envTplRender($template)
{
	global $renderer;

	$ostemplate = pnVarPrepForOS($template).'.tpl';
	$renderer->display($ostemplate);
	return true;
}


////
// Return template output for advanced placement
// @access		public
// @author		mh7
// @param		string	$template	the template to return
// @return		mixed				the template output
function envTplFetch($template)
{
	global $renderer;

	$ostemplate = pnVarPrepForOS($template).'.tpl';
	return $renderer->fetch($ostemplate);
}


////
// Load the template engine
// @access		private
// @author		mh7
// @param		none
// @return		bool				true
function envTplLoadEngine()
{
	if (class_exists('Smarty'))
    {
		return true;
	} else {
        // Get Encompass module info
        $modinfo = pnModGetInfo(pnModGetIDFromName('Encompass'));

        if (!empty($modinfo))
        {
            // Load the DTS (Smarty) Class
            include_once('modules/'.$modinfo['directory'].'/pnclasses/Smarty.class.php');
			return true;
        }
    }

	return false;
}


////
// Get the modules template path
// @access		private
// @author		mh7
// @param		string	$module		the name of the module
// @param		string	$template	the name of the template
// @param		string	$theme		the name of the active theme
// @return		string	$tplpath	the template path
function envTplGetPath($module, $template, $theme)
{
	$tplpath = envTplCheckPath($module, $template, $theme, 'templates');
	return $tplpath;
}


////
// Setup the module images path
// @access		private
// @author		mh7
// @param		string	$module		the name of the module
// @param		string	$template	the name of the template
// @param		string	$theme		the name of the active theme
// @return		string	$imgpath	the image path
function envTplImagePath($module, $template)
{
	// Determine which Theme to use
    if (pnUserLoggedIn())
    {
        // Use the users Theme
        $theme = pnUserGetTheme();
    } else {
        // Use the sites theme
        $theme = pnConfigGetVar('Default_Theme');
    }

	$imgpath = envTplCheckPath($module, $template, $theme, 'images');
	return $imgpath;
}


////
// Check the path(s) available
// @access		private
// @author		mh7
// @param		string	$module		the module name
// @param		string	$template	the name of the template
// @param		string	$theme		the name of the current theme
// @param		string	$type		the type of directory needed (tpl/img)
// @return		string	$path		the path to use
function envTplCheckPath($module, $template, $theme, $type='templates')
{
	// Check for theme specific module template
	$ostemplate = pnVarPrepForOS($template).'.tpl';

	// Check for a Theme specific template
    if (file_exists('themes/'.$theme.'/templates/'.$ostemplate))
	{
		$path = 'themes/'.$theme.'/'.$type;
	} else {
		// Get the calling modules info
		$modinfo = pnModGetInfo(pnModGetIDFromName($module));

		$path = 'modules/'.$modinfo['directory'].'/pn'.$type;
	}

	return $path;
}


?>