<?php
// File: $Id: pnuserapi.php,v 1.2 2002/09/17 15:11:02 thelinu Exp $ $Name:  $
// ----------------------------------------------------------------------------
// Envolution Content Management System
// Copyright (C) 2002 by the Envolution Development Team.
// http://www.envolution.com/
// ----------------------------------------------------------------------------
// Based on:
// Postnuke Content Management System - www.postnuke.com
// PHP-NUKE Web Portal System - http://phpnuke.org/
// ----------------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------------
// Original Author of file: Gregor J. Rothfuss
// Purpose of file: Implement XML-RPC backend
// ----------------------------------------------------------------------------


/**
 * Initialise the installed XML-RPC server APIs
 * <br>
 * Carries out a number of initialisation tasks to get XML-RPC up and
 * running.
 * @returns void
 */
function xmlrpc_userapi_initServer()
{
  // include XML-RPC libraries
  include_once 'modules/xmlrpc/lib/xmlrpc.inc';
  include_once 'modules/xmlrpc/lib/xmlrpcs.inc';

  // include the various APIs (hardcoded for now)
  include_once 'modules/xmlrpc/api/blogger.php';
    // merge blogger functions
    #$functions = $_xmlrpc_blogger_dmap;
    $functions = array_merge($_xmlrpc_blogger_dmap, $_xmlrpc_syncacross_dmap);

  //create server instance
  $server = new xmlrpc_server($functions);
  if (!$server) {
    die("xmlrpc_userapi_initServer: can't create server");
  }
  return $server;
}

/**
 * Initialise the XML-RPC client libraries
 * <br>
 * Carries out a number of initialisation tasks to get XML-RPC up and
 * running.
 * @returns void
 */
function xmlrpc_userapi_initClient()
{
  // include XML-RPC libraries
  include_once 'modules/xmlrpc/lib/xmlrpc.inc';
  include_once 'modules/xmlrpc/lib/xmlrpcs.inc';

  return true;
}

/**
 * Call a remote XML-RPC method
 * <br>
 * Opens an XML-RPC connection
 * with the specified parameters.
 * @returns resultrarray
 */
function xmlrpc_userapi_call($methodname, $params, $endpoint)
{
  $debugOn = 0;  // 0 = off ; 1 = on
  // intialize client
  xmlrpc_userapi_initClient();

  /**
   * $endpoint stands for the XML-RPC server and could be i.e.
   * $endpoint['site'] = "www.targethostname.com";  // could be "localhost"
   * $endpoint['port'] = 80;   // SSL is possible, but read the xmlrpc (php) docs on http://www.usefulinc.com/xmlrpc/
   * $endpoint['path'] = "/xmlrpc.php";  // this is correct for PN 0.71x
   *
   * $methodname could be i.e.
   * - "blogger.getUserInfo" with params appkey, username and password
   * - "blogger.getUsersBlogs" with params appkey, username and password
   * - "system.listMethods" without any params (but an empty params array)
   * Have a look at source of /modules/xmlrpc/api/blogger.php and /modules/xmlrpc/libs/xmlrpcs.php for further details
   *
   * $params for the chosen method should have been created like this:
   * $params = array();
   * $params[] = array("value"=>md5(uniqid (rand())),"type"=>"string");  // appkey
   * $params[] = array("value"=>"fooname","type"=>"string");  // username (when connecting to a PN site, then of course a PN username)
   * $params[] = array("value"=>"Pa5Sw0rd","type"=>"string");  // password
   */

  $params_extracted = array();
  if (isset($params))
      foreach($params AS $index => $var)
      {
        $params_extracted[] = new xmlrpcval($var['value'],$var['type']);
      }

//#    print "<br>methodname: $methodname<pre>params_extracted"; print_r($params_extracted); print "</pre>";

//#    $pars = array(new xmlrpcval($name), new xmlrpcval($url));

  // build the XML-RPC call and execute it
  $f=new xmlrpcmsg($methodname, $params_extracted);
  $c=new xmlrpc_client($endpoint['path'], $endpoint['site'], $endpoint['port']);
  $c->setDebug($debugOn);

  $r=$c->send($f);

  if (!$r) { die('xmlrpc_userapi_call: send failed'); }
  $v=$r->value();

  if (!$r->faultCode()) {
     $result = array();

     if ($v->scalartyp() == "array")
     {
//#print "<br><pre>v: "; print_r($v); print "</pre>";
        // xml response is an array of objects
        for ($i = 0; $i < $v->arraysize(); $i++)
        {
           $val = $v->arraymem($i);
//#print "scalartyp: ". $val->scalartyp()."<br>";
           if ($val->scalartyp() == "struct")
           {
                while(list($key,$value)=$val->structeach())
                {
                   $result[$i][$key] = $value->scalarval();
                }
           } else {
                // hopefully the scalartyp is not 'array' but something like 'string' or 'int'
                // need to check this out in next version
//#print "arraysize: ". $val->arraysize() ."<br>";
//#                for ($j = 0; $j < $val->arraysize(); $j++)
//#                {
//#                   $result[$j] = $val->scalarval();
//#                }
                $result[$i] = $val->scalarval();
           }
         }
     } else {
//#print "<br><pre>v:"; print_r($v); print "</pre>";
        // xml response is a scalar object
        while(list($key,$value)=$v->structeach())
        {
           $result[$key] = $value->scalarval();
        }

     }
  } else {
    $result = 'Fault. Code: '.$r->faultCode().' Reason '.$r->faultString();
  }
  return $result;
}

function xmlrpc_userapi_get_userid($username) {
    $pntable = pnDBGetTables();
    list($dbconn) = pnDBGetConn();
        $cols = &$pntable['users_column'];

    $result = $dbconn->Execute("SELECT  $cols[uid] from $pntable[users] where $cols[uname] ='$username'");
    $uid = $result->fields[0];
    return $uid;
}


?>
